<?php

declare(strict_types=1);

namespace Drupal\cache_control_override_test\Controller;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\HttpFoundation\Response;

/**
 * Test caching with a max age provided from the URL.
 */
final class CacheControl {

  /**
   * Test content with a specified max age.
   *
   * @param string $max_age
   *   Max age value to be used in the response.
   *
   * @return array|\Symfony\Component\HttpFoundation\Response
   *   The response.
   */
  public function __invoke(mixed $max_age = CacheBackendInterface::CACHE_PERMANENT): array|Response {
    return [
      '#markup' => new TranslatableMarkup('Max age test content: @max_age', [
        '@max_age' => $max_age,
      ]),
      '#cache' => ['max-age' => $max_age],
    ];
  }

}
