<?php

declare(strict_types=1);

namespace Drupal\Tests\cache_control_override\Functional;

use Drupal\Core\Url;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests the cache control override.
 *
 * @group cache_control_override
 */
final class CacheControlOverrideMaxAgeTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'cache_control_override',
    'cache_control_override_test',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->config('system.performance')
      ->set('cache.page.max_age', 3600)
      ->save();
  }

  /**
   * Test the cache properties in response header data.
   */
  public function testMaxAge(): void {
    $this->drupalGet(Url::fromRoute('cache_control_override_test.max_age'));
    $this->assertSession()->responseContains('Max age test content');
    $this->assertSession()->responseHeaderContains('Cache-Control', 'max-age=3600, public');

    $this->drupalGet(Url::fromRoute('cache_control_override_test.max_age', route_parameters: [
      'max_age' => '333',
    ]));
    $this->assertSession()->responseHeaderContains('Cache-Control', 'max-age=333, public');

    $this->drupalGet(Url::fromRoute('cache_control_override_test.max_age', route_parameters: [
      'max_age' => '0',
    ]));
    $this->assertSession()->responseHeaderContains('Cache-Control', 'max-age=0, public');
  }

}
